@@ -56,27 +56,23 @@ class NMEAHandler:
                 self._process_RMC(parsed_data)
             elif parsed_data.msgID == "GGA":  # GPS Fix Data
                 self._process_GGA(parsed_data)
-            elif parsed_data.msgID in ("GLL"):  # GPS Lat Lon Data
+            elif parsed_data.msgID == "GLL":  # GPS Lat Lon Data
                 self._process_GLL(parsed_data)
-            elif parsed_data.msgID in ("GNS"):  # GNSS Fix Data
+            elif parsed_data.msgID == "GNS":  # GNSS Fix Data
                 self._process_GNS(parsed_data)
             elif parsed_data.msgID == "GSA":  # GPS DOP (Dilution of Precision)
                 self._process_GSA(parsed_data)
-            elif (
-                parsed_data.msgID == "VTG"
-            ):  # GPS Vector track and Speed over the Ground
+            elif parsed_data.msgID == "VTG":  # GPS Vector track and Speed over Ground
                 self._process_VTG(parsed_data)
             elif parsed_data.msgID == "GSV":  # GPS Satellites in View
                 self._process_GSV(parsed_data)
             elif parsed_data.msgID == "ZDA":  # ZDA Time
                 self._process_ZDA(parsed_data)
-            elif (
-                parsed_data.msgID == "UBX" and parsed_data.msgId == "00"
-            ):  # GPS Lat/Lon & Acc Data
+            # proprietary GPS Lat/Lon & Acc
+            elif parsed_data.msgID == "UBX" and parsed_data.msgId == "00":
                 self._process_UBX00(parsed_data)
 
         except ValueError:
-            # self.__app.set_status(NMEAVALERROR.format(err), "red")
             pass
 
     def _process_RMC(self, data: NMEAMessage):
